Learn R Programming

geometry (version 0.3-3)

bary2cart: Conversion of Barycentric to Cartesian coordinates

Description

Given the baryocentric coordinates of one or more points with respect to a simplex, compute the Cartesian coordinates of these points.

Usage

bary2cart(X, Beta)

Arguments

X
Reference simplex in $N$ dimensions represented by a $N+1$-by-$N$ matrix
Beta
$M$ points in baryocentric coordinates with respect to the simplex X represented by a $M$-by-$N+1$ matrix

Value

  • $M$-by-$N$ matrix in which each row is the Cartesian coordinates of corresponding row of Beta