The Delaunay triangulation is a tessellation of the convex hull of
the points such that no N-sphere defined by the N-triangles
contains any other points from the set.
Usage
delaunayn(p, options = "", full = FALSE)
Arguments
p
p is an n-by-dim matrix. The rows of p
represent n points in dim-dimensional space.
options
String containing extra options for the underlying
Qhull command.(See the Qhull documentation
(../doc/html/qdelaun.html) for the available options.)
full
Return all information asscoiated with triangulation
as a list. At present this is the triangulation (tri), a
vector of facet areas (areas) and a list of neighbours of
each facet (neighbours).
Value
The return matrix has m rows and dim+1
columns. It contains for each row a set of indices to the points,
which describes a simplex of dimension dim. The 3D simplex
is a tetrahedron.
Details
If neither of the QJ or Qt options are supplied, the
Qt option is passed to Qhull. The Qt option ensures
all Delaunay regions are simplical (e.g., triangles in 2-d). See
../doc/html/qdelaun.html for more details. Contrary to the
Qhull documentation, no degenerate (zero area) regions are
returned with the Qt option since the R function removes
them from the triangulation.
For slient operation, specify the option Pp.
References
Barber, C.B., Dobkin, D.P., and Huhdanpaa, H.T.,
The Quickhull algorithm for convex hulls,ACM Trans. on
Mathematical Software, Dec 1996.