The Delaunay triangulation is a tessellation of the
convex hull of the points such that no N-sphere defined
by the N-triangles contains any other points from the
set.
Usage
delaunayn(p, options = "")
Arguments
p
p is an n-by-dim matrix.
The rows of p represent n points in
dim-dimensional space.
options
String containing extra options for the
underlying Qhull command.(See the Qhull documentation
(../doc/html/qdelaun.html) for the available
options.)
Value
The return matrix has m rows and dim+1
columns. It contains for each row a set of indices to the
points, which describes a simplex of dimension
dim. The 3D simplex is a tetrahedron.
Details
The Qt option is supplied to Qhull by default. The
code ensures that one of Qt or QJ is passed
to Qhull. See ../doc/html/qdelaun.html for more
details.
For slient operation, specify the option Pp.
References
Barber, C.B., Dobkin, D.P., and Huhdanpaa, H.T.,
The Quickhull algorithm for convex hulls,ACM Trans. on Mathematical Software, Dec 1996.